Documentation
¶
Index ¶
- func GenerateWallet(filePath string, password []byte) (address string, err error)
- func GetBalance(ctx context.Context, filePath string) (*model.SolanaBalanceResponse, error)
- func GetTransactions(ctx context.Context, filePath string, req *model.LogRequest) (*model.LogResponse, error)
- func IsFileExistsError(err error) bool
- func PaySOL(ctx context.Context, filePath string, password []byte, ...) (*model.PayResponse, error)
- func PayUSDC(ctx context.Context, filePath string, password []byte, ...) (*model.PayResponse, error)
- type FileExistsError
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateWallet ¶
GenerateWallet generates a new Solana wallet and saves it to .cwt file. Returns the generated public address on success. password must be []byte for security (caller should zero it after use)
func GetBalance ¶
GetBalance gets wallet balance
func GetTransactions ¶
func GetTransactions(ctx context.Context, filePath string, req *model.LogRequest) (*model.LogResponse, error)
GetTransactions gets wallet transactions with filtering
func IsFileExistsError ¶
IsFileExistsError checks if error is FileExistsError
Types ¶
type FileExistsError ¶
type FileExistsError struct {
Message string
}
FileExistsError is an error when file already exists and is not empty
func (*FileExistsError) Error ¶
func (e *FileExistsError) Error() string
Click to show internal directories.
Click to hide internal directories.